
# THIS FILE IS GENERATED FROM PYWAVELETS SETUP.PY
short_version = '1.0.3'
version = '1.0.3'
full_version = '1.0.3'
git_revision = 'd57fdfef1a14360f1295778b076d0ca0dbd9ef22'
release = True

if not release:
    version = full_version
